package de.uni.kiel.proki.ws1112.muehle.interfaces;

/**
 * Jedes Spielbrett von Muehle soll dieses Interface erfuellen.
 * 
 * @author wzo
 */
public interface ModelInterface {

	/**
	 * Liefert den Status des gewaehlten Feldes.
	 * Wenn dieses Feld nicht zum Muehle Spiel gehoert,
	 * wir eine GameException geworfen
	 *
	 * @param spalte - gewuenschte Spalte
	 * @param zeile - gewuenschte Zeile
	 * @return BLACK, WHITE oder EMPTY
	 * @throws GameException
	 */
	public Token getFieldStatus(int x, int y) throws GameException;

	/**
	 * Setzt das gegebene Token in das gewuenschte Feld.
	 * Wenn dieses Feld nicht zum Muehle Spiel gehoert,
	 * wir eine GameException geworfen
	 *
	 * @param x - gewuenschte Spalte
	 * @param y - gewuenschte Zeile
	 * @param tok - gewuenschter Status
	 * @throws GameException
	 */
	public boolean setFieldStatus(int x, int y, Token tok) throws GameException;
	
	/**
	 * Entfernt das gegebene Token aus dem gewuenschten Feld.
	 * Wenn dieses Feld nicht zum Muehle Spiel gehoert,
	 * wir eine GameException geworfen
	 * 
	 * @param player der Spieler,
	 * der einen Stein auf diesem Feld haben soll
	 * 
	 * @param x - gewuenschte Spalte
	 * @param y - gewuenschte Zeile
	 * @return true == Stein entnommen
	 * 		   false == Stein nicht entnommen,
	 *  				da Feld leer oder vom anderen Spieler
	 * @throws GameException
	 */
	public boolean removeStoneAtPosition(PlayerInterface player, int x, int y) throws GameException;
	
	/** 
	 * Liefert die Breite des Spielfeldes (Anzahl der Felder)
	 */
	public int getWidth();

	/** 
	 * Liefert die Hoehe des Spielfeldes (Anzahl der Felder)  
	 */
	public int getHeight();

}
